@@ -233,7 +233,7 @@ impl<T> RingBuffer<T> {
     /// # use ring_buffer::RingBuffer;
     /// #
     /// let mut buffer = RingBuffer::new();
-    /// assert_eq!(buffer.back_absolute_index(), None);
+    /// assert!(buffer.back_absolute_index().is_none());
     ///
     /// buffer.push_back(1);
     /// buffer.push_back(2);
@@ -372,7 +372,7 @@ impl<T> RingBuffer<T> {
     /// # use ring_buffer::RingBuffer;
     /// #
     /// let mut buffer = RingBuffer::new();
-    /// assert_eq!(buffer.front_absolute_index(), None);
+    /// assert!(buffer.front_absolute_index().is_none());
     ///
     /// buffer.push_back(1);
     /// buffer.push_back(2);
@@ -1099,6 +1099,15 @@ impl<T> RingBuffer<T> {
     }
 }
 
+impl RingBufferIndex {
+    /// Uses the buffer to resolve any aliasing that can occur because of a growing buffer and wrap-
+    /// around.
+    #[inline]
+    pub fn eq<T>(self, buffer: &RingBuffer<T>, other: Self) -> bool {
+        buffer.resolve_index(self) == buffer.resolve_index(other)
+    }
+}
+
 impl<T> Clone for RingBuffer<T>
 where
     T: Clone,
@@ -1294,15 +1303,6 @@ where
 unsafe impl<T> Send for RingBuffer<T> where T: Send {}
 unsafe impl<T> Sync for RingBuffer<T> where T: Sync {}
 
-impl PartialEq for RingBufferIndex {
-    /// This is partially flawed as indices can be aliased in a way that two indices point to the
-    /// same element. The [`RingBuffer`] struct is needed to resolve the aliasing, but it's not
-    /// available here.
-    fn eq(&self, other: &Self) -> bool {
-        (self.base_index + self.wrap_offset) == (other.base_index + other.wrap_offset)
-    }
-}
-
 /// An iterator over the elements of a `RingBuffer`.
 ///
 /// This `struct` is created by the [`iter`] method on [`RingBuffer`]. See its
@@ -1501,20 +1501,20 @@ mod tests {
         for i in 1..=8 {
             indices.push(buffer.push_back(i));
         }
-        assert_eq!(
-            indices.first().unwrap(),
-            &RingBufferIndex {
+        assert!(indices[0].eq(
+            &buffer,
+            RingBufferIndex {
                 base_index: 0,
                 wrap_offset: 0
             }
-        );
-        assert_eq!(
-            indices.last().unwrap(),
-            &RingBufferIndex {
+        ));
+        assert!(indices[7].eq(
+            &buffer,
+            RingBufferIndex {
                 base_index: 7,
                 wrap_offset: 0
             }
-        );
+        ));
         assert_eq!(buffer.capacity, 8);
         assert_eq!(buffer.as_slices(), (&[1, 2, 3, 4, 5, 6, 7, 8][..], &[][..]));
         for i in 0..8 {
@@ -1535,34 +1535,34 @@ mod tests {
         for i in 9..=12 {
             indices.push(buffer.push_back(i));
         }
-        assert_eq!(
-            indices[0],
+        assert!(indices[0].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 4,
                 wrap_offset: 0
             }
-        );
-        assert_eq!(
-            indices[3],
+        ));
+        assert!(indices[3].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 7,
                 wrap_offset: 0
             }
-        );
-        assert_eq!(
-            indices[4],
+        ));
+        assert!(indices[4].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 0,
                 wrap_offset: 8
             }
-        );
-        assert_eq!(
-            indices[7],
+        ));
+        assert!(indices[7].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 3,
                 wrap_offset: 8
             }
-        );
+        ));
         assert_eq!(buffer.capacity, 8);
         assert_eq!(
             buffer.as_slices(),
@@ -1572,20 +1572,20 @@ mod tests {
         for i in 13..=16 {
             indices.push(buffer.push_back(i));
         }
-        assert_eq!(
-            indices[8],
+        assert!(indices[8].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 12,
                 wrap_offset: 0
             }
-        );
-        assert_eq!(
-            indices[11],
+        ));
+        assert!(indices[11].eq(
+            &buffer,
             RingBufferIndex {
                 base_index: 15,
                 wrap_offset: 0
             }
-        );
+        ));
         assert_eq!(buffer.capacity, 16);
         assert_eq!(
             buffer.as_slices(),
